@@ -194,6 +194,8 @@ class Config:
     #: Standard application urls. If defined to a valid url appropriate actions
     #: are defined in various contexts
     APPLICATION_URLS = {
+        #: FAQ
+        "FAQ": None,
         #: Submit a bug report action in the Help menu
         "Bug Report": None,
         #: A url quick tour/getting started url
@@ -204,6 +206,8 @@ class Config:
         "Screencasts": None,
         #: Used for 'Submit Feedback' action in the help menu
         "Feedback": None,
+        #: A Donate action in the help menu
+        "Donate": None,
     }  # type: Dict[str, Optional[str]]
 
 
@@ -434,7 +438,7 @@ spec = \
 
      ("logging/dockable", bool, True, "Allow log window to be docked"),
 
-     ("help/open-in-external-browser", bool, False,
+     ("help/open-in-external-browser", bool, True,
       "Open help in an external browser"),
 
      ("add-ons/allow-conda", bool, True,
@@ -446,6 +450,8 @@ spec = \
      ("network/http-proxy", str, '', 'HTTP proxy.'),
 
      ("network/https-proxy", str, '', 'HTTPS proxy.'),
+
+     ("network/use-certs", bool, False, "Use system certificates."),
      ]
 
 
