@@ -35,7 +35,7 @@ from AnyQt.QtGui import (
     QWhatsThisClickedEvent, QKeyEvent, QPalette
 )
 from AnyQt.QtCore import (
-    Qt, QObject, QEvent, QSignalMapper, QCoreApplication, QPointF,
+    Qt, QObject, QEvent, QSignalMapper, QCoreApplication, QPointF, QRectF,
     QMimeData, Slot)
 from AnyQt.QtCore import pyqtProperty as Property, pyqtSignal as Signal
 
@@ -51,7 +51,7 @@ from ..gui.utils import (
 )
 from ..scheme import (
     scheme, signalmanager, Scheme, SchemeNode, SchemeLink,
-    BaseSchemeAnnotation, SchemeTextAnnotation, WorkflowEvent
+    BaseSchemeAnnotation, SchemeTextAnnotation, WorkflowEvent, SchemeArrowAnnotation
 )
 from ..scheme.widgetmanager import WidgetManager
 from ..canvas.scene import CanvasScene
@@ -224,6 +224,9 @@ class SchemeEditWidget(QWidget):
         self.__editMenu.addAction(self.__copySelectedAction)
         self.__editMenu.addAction(self.__pasteAction)
         self.__editMenu.addAction(self.__selectAllAction)
+        self.__editMenu.addSeparator()
+        self.__editMenu.addAction(self.__newQuickTextAnnotationAction)
+        self.__editMenu.addAction(self.__newQuickArrowAnnotationAction)
 
         # Widget context menu
         self.__widgetMenu = QMenu(self.tr("Widget"), self)
@@ -293,6 +296,13 @@ class SchemeEditWidget(QWidget):
 
         self.__newTextAnnotationAction.setMenu(self.__fontMenu)
 
+        self.__newQuickTextAnnotationAction = QAction(
+            self.tr("Text Annotation"), self,
+            objectName="new-quick-text-annotation-action",
+            toolTip=self.tr("Add a text annotation to the workflow."),
+            triggered=self.__triggerNewTextAnnotation
+        )
+
         self.__newArrowAnnotationAction = QAction(
             self.tr("Arrow"), self,
             objectName="new-arrow-action",
@@ -332,6 +342,13 @@ class SchemeEditWidget(QWidget):
 
         self.__newArrowAnnotationAction.setMenu(self.__arrowColorMenu)
 
+        self.__newQuickArrowAnnotationAction = QAction(
+            self.tr("Arrow Annotation"), self,
+            objectName="new-quick-arrow-annotation-action",
+            toolTip=self.tr("Add a arrow annotation to the workflow."),
+            triggered=self.__triggerNewArrowAnnotation,
+        )
+
         self.__undoAction = self.__undoStack.createUndoAction(self)
         self.__undoAction.setShortcut(QKeySequence.Undo)
         self.__undoAction.setObjectName("undo-action")
@@ -1896,7 +1913,7 @@ class SchemeEditWidget(QWidget):
             handler = self.__scene.user_interaction_handler
             if isinstance(handler, interactions.NewArrowAnnotation):
                 # Cancel the interaction and restore the state
-                handler.ended.disconnect(action.toggle)
+                handler.ended.disconnect(self.__toggleNewArrowAction)
                 handler.cancel(interactions.UserInteraction.UserCancelReason)
                 log.info("Canceled new arrow annotation")
 
@@ -1905,10 +1922,18 @@ class SchemeEditWidget(QWidget):
             checked_action = self.__arrowColorActionGroup.checkedAction()
             handler.setColor(checked_action.data())
 
-            handler.ended.connect(action.toggle)
+            handler.ended.connect(self.__toggleNewArrowAction)
 
             self._setUserInteractionHandler(handler)
 
+    def __toggleNewArrowAction(self):
+        handler = self.sender()
+        action = self.__newArrowAnnotationAction
+        action.toggle()  # end current
+        if handler.extendedOnShift:
+            handler.extendedOnShift = False  # clear shift flag
+            action.toggle()  # start new
+
     def __onFontSizeTriggered(self, action):
         # type: (QAction) -> None
         if not self.__newTextAnnotationAction.isChecked():
@@ -1959,6 +1984,38 @@ class SchemeEditWidget(QWidget):
             if isinstance(handler, interactions.NewArrowAnnotation):
                 handler.setColor(action.data())
 
+    def __triggerNewTextAnnotation(self):
+        """Place a text annotation at the center of the view"""
+        center = self.view().viewport().rect().center()
+        center = self.view().mapToScene(center)
+        rect = QRectF(0, 0, 300, 150)
+        rect.moveCenter(center)
+        annotation = SchemeTextAnnotation(
+            (rect.x(), rect.y(), rect.width(), rect.height()),
+            content_type="text/markdown",
+        )
+        self.addAnnotation(annotation)
+        # Give edit focus
+        item = self.scene().item_for_annotation(annotation)
+        item.setFocus(Qt.OtherFocusReason)
+        item.setSelected(True)
+        item.startEdit()
+
+    def __triggerNewArrowAnnotation(self):
+        """Place an arrow annotation at the center of the view"""
+        center = self.view().viewport().rect().center()
+        center = self.view().mapToScene(center)
+
+        annotation = SchemeArrowAnnotation(
+            (center.x() - 100, center.y()), (center.x() + 100, center.y()),
+            color=self.__arrowColorActionGroup.checkedAction().data()
+        )
+        self.addAnnotation(annotation)
+        # Give edit focus
+        item = self.scene().item_for_annotation(annotation)
+        item.setFocus(Qt.OtherFocusReason)
+        item.setSelected(True)
+
     def __onRenameAction(self):
         # type: () -> None
         """
